Enum scte35_reader::SpliceDescriptorErr[][src]

pub enum SpliceDescriptorErr {
    InvalidDescriptorLength(usize),
    NotEnoughData {
        field_name: &'static str,
        expected: usize,
        actual: usize,
    },
    SegmentationUpidLengthTypeMismatch(SegmentationUpidType),
    InvalidUpidContent {
        upid_type: SegmentationUpidType,
        bytes: Vec<u8>,
    },
    InvalidUpidLength {
        upid_type: SegmentationUpidType,
        expected: usize,
        actual: usize,
    },
}

Variants

InvalidDescriptorLength(usize)
NotEnoughData

Fields of NotEnoughData

field_name: &'static strexpected: usizeactual: usize
SegmentationUpidLengthTypeMismatch(SegmentationUpidType)

The segmentation_upid_length field value was 0, but the segmentation_upid_type value was non-0 (as indicated by the given SegmentationUpidType enum variant)

InvalidUpidContent

The UPID field contained byte values that are invalid for the given UPID type

Fields of InvalidUpidContent

upid_type: SegmentationUpidTypebytes: Vec<u8>
InvalidUpidLength

The UPID field had a length invalid for its type

Fields of InvalidUpidLength

upid_type: SegmentationUpidTypeexpected: usizeactual: usize