Struct scte35_reader::Scte35SectionProcessor [−][src]
pub struct Scte35SectionProcessor<P, Ctx: DemuxContext> where
P: SpliceInfoProcessor, { /* fields omitted */ }
Methods
impl<P, Ctx: DemuxContext> Scte35SectionProcessor<P, Ctx> where
P: SpliceInfoProcessor, [src]
impl<P, Ctx: DemuxContext> Scte35SectionProcessor<P, Ctx> where
P: SpliceInfoProcessor, pub fn new(processor: P) -> Scte35SectionProcessor<P, Ctx>[src]
pub fn new(processor: P) -> Scte35SectionProcessor<P, Ctx>Trait Implementations
impl<P, Ctx: DemuxContext> SectionProcessor for Scte35SectionProcessor<P, Ctx> where
P: SpliceInfoProcessor, [src]
impl<P, Ctx: DemuxContext> SectionProcessor for Scte35SectionProcessor<P, Ctx> where
P: SpliceInfoProcessor, type Context = Ctx
fn start_section<'a>(
&mut self,
_ctx: &mut Self::Context,
header: &SectionCommonHeader,
data: &'a [u8]
)[src]
fn start_section<'a>(
&mut self,
_ctx: &mut Self::Context,
header: &SectionCommonHeader,
data: &'a [u8]
)Note that the first 3 bytes of section_data contain the header fields that have also been supplied to this call in the header parameter. This is to allow implementers to calculate a CRC over the whole section if required. Read more
fn continue_section<'a>(
&mut self,
_ctx: &mut Self::Context,
_section_data: &'a [u8]
)[src]
fn continue_section<'a>(
&mut self,
_ctx: &mut Self::Context,
_section_data: &'a [u8]
)fn reset(&mut self)[src]
fn reset(&mut self)Auto Trait Implementations
impl<P, Ctx> Send for Scte35SectionProcessor<P, Ctx> where
Ctx: Send,
P: Send,
impl<P, Ctx> Send for Scte35SectionProcessor<P, Ctx> where
Ctx: Send,
P: Send, impl<P, Ctx> Sync for Scte35SectionProcessor<P, Ctx> where
Ctx: Sync,
P: Sync,
impl<P, Ctx> Sync for Scte35SectionProcessor<P, Ctx> where
Ctx: Sync,
P: Sync,