Struct scte35_reader::SpliceInfoHeader [−][src]
Header element within a SCTE-43 splice_info_section containing metadata generic across all kinds of splice-command.
This is a wrapper around a byte-slice that will extract requested fields on demand, as its methods are called.
Implementations
impl<'a> SpliceInfoHeader<'a>[src]
pub fn new(buf: &'a [u8]) -> (SpliceInfoHeader<'a>, &'a [u8])[src]
Splits the given buffer into a SpliceInfoHeader element, and a remainder which will
include the splice-command itself, plus any descriptor_loop.
pub fn protocol_version(&self) -> u8[src]
The version of the SCTE-35 data structures carried in this splice_info_section (only
version 0 is supported by this library).
pub fn encrypted_packet(&self) -> bool[src]
Indicates that portions of this splice_info_section are encrypted (only un-encrypted data is supported by this library).
pub fn encryption_algorithm(&self) -> EncryptionAlgorithm[src]
The algorithm by which portions of this splice_info_section are encrypted (only un-encrypted data is supported by this library).
pub fn pts_adjustment(&self) -> u64[src]
A 33-bit adjustment value to be applied to any PTS value in a splice-command within this splice_info_section.
pub fn cw_index(&self) -> u8[src]
Identifier for the ‘control word’ (key) used to encrypt the message, if encrypted_packet
is true.
pub fn tier(&self) -> u16[src]
12-bit authorization tier.
pub fn splice_command_length(&self) -> u16[src]
Length in bytes of the splice-command data within this message.
pub fn splice_command_type(&self) -> SpliceCommandType[src]
Type of splice-command within this message.