Enum scte35_reader::SpliceDescriptorErr [−][src]
Variants
InvalidDescriptorLength(usize)SegmentationUpidLengthTypeMismatch(SegmentationUpidType)The segmentation_upid_length field value was 0, but the segmentation_upid_type value was
non-0 (as indicated by the given SegmentationUpidType enum variant)
The UPID field contained byte values that are invalid for the given UPID type
Fields of InvalidUpidContent
upid_type: SegmentationUpidTypebytes: Vec<u8>The UPID field had a length invalid for its type
Fields of InvalidUpidLength